@@ -273,18 +273,6 @@ download() {
     wget -nv $VERBOSE --no-check-certificate -O "$@";
 }
 
-download_from_pypi () {
-    local pkg=$1
-    local url=$(download - "$BASE_PIP_URL"/"$pkg"/ | sed -n '/source\/.\/'"$pkg"'.*gz/ { s:.*href="\([^#"]*\)["#].*:\1:g; p; }' | sort | tail -1)
-    if [ -n "$url" ]; then
-        download "$(basename "$url")" "$BASE_PIP_URL"/"$pkg"/"$url"
-    else
-        die $EX_PROTOCOL "Package '$pkg' not found on PyPI!" <<__EOF__
-Unable to download package '$pkg' from PyPI.
-__EOF__
-    fi
-}
-
 install_required_sw () {
     # instead of guessing which distribution this is, we check for the
     # package manager name as it basically identifies the distro
@@ -298,8 +286,17 @@ install_required_sw () {
         else
             pkg_manager="apt-get install"
         fi
+    elif have_command dnf; then
+        # dnf based RHEL/CentOS/Fedora
+        missing=$(which_missing_packages gcc libffi-devel python-devel openssl-devel gmp-devel libxml2-devel libxslt-devel postgresql-devel redhat-rpm-config git wget)
+
+        if [ "$ASKCONFIRMATION" -eq 0 ]; then
+            pkg_manager="dnf install -y"
+        else
+            pkg_manager="dnf install"
+        fi
     elif have_command yum; then
-        # RHEL/CentOS
+        # yum based RHEL/CentOS/Fedora
         missing=$(which_missing_packages gcc libffi-devel python-devel openssl-devel gmp-devel libxml2-devel libxslt-devel postgresql-devel redhat-rpm-config git wget)
 
         if [ "$ASKCONFIRMATION" -eq 0 ]; then
@@ -425,30 +422,18 @@ __EOF__
     download "$VIRTUALENV_DST" "$VIRTUALENV_191_URL"
     "$PYTHON" "$VIRTUALENV_DST" $VERBOSE -p "$PYTHON" "$DESTDIR"
 
-    . "$DESTDIR"/bin/activate
+    cd "${DESTDIR}" && . bin/activate
 
-    # Recent versions of `pip` insist that setuptools>=0.8 is installed,
-    # because they try to use the "wheel" format for any kind of package.
-    # So we need to update setuptools, or `pip` will error out::
-    #
-    #     Wheel installs require setuptools >= 0.8 for dist-info support.
-    #
-    if pip wheel --help 1>/dev/null 2>/dev/null; then
-        (cd "$DESTDIR" && download_from_pypi setuptools)
-        # setup.py must be called with `python', which will be the
-        # python executable inside the virtualenv, not `$PYTHON',
-        # which is the system python.
-        if ! (cd "$DESTDIR" && tar -xzf setuptools-*.tar.gz && \
-              cd setuptools-* && python setup.py install);
-        then
-            die $EX_SOFTWARE \
-                "Failed to install the latest version of Python 'setuptools'" <<__EOF__
+    # Setuptools>=0.8 is required to support "wheel" format, otherwise
+    # pip will fail with an error. To be sure, just run upgrade to the
+    # recent version of setuptools
+    download - https://bootstrap.pypa.io/ez_setup.py | python - --insecure\
+        || die ${EX_SOFTWARE}\
+            "Failed to install the latest version of Python 'setuptools'" <<__EOF__
 
 The required Python package setuptools could not be installed.
 
 __EOF__
-        fi
-    fi
 }
 
 setup_rally_configuration () {
