@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-""" Rally command: task """
+"""Rally command: task"""
 
 from __future__ import print_function
 import json
@@ -36,6 +36,7 @@ from rally.common.i18n import _
 from rally.common import junit
 from rally.common import logging
 from rally.common import utils as rutils
+from rally.common import version
 from rally import consts
 from rally import exceptions
 from rally import plugins
@@ -138,7 +139,7 @@ class TaskCommands(object):
             if task_instance:
                 task_instance.set_failed(err.__class__.__name__,
                                          str(err),
-                                         json.dumps(traceback.format_stack()))
+                                         json.dumps(traceback.format_exc()))
             raise
         api.Task.validate(deployment, input_task, task_instance)
         print(_("Task config is valid :)"))
@@ -236,6 +237,7 @@ class TaskCommands(object):
         task_instance = api.Task.create(deployment, tag)
 
         try:
+            print("Running Rally version", version.version_string())
             input_task = self._load_and_validate_task(
                 task, task_args, task_args_file, deployment,
                 task_instance=task_instance)
@@ -325,11 +327,11 @@ class TaskCommands(object):
             print("-" * 80)
             verification = yaml.safe_load(task["verification_log"])
             if logging.is_debug():
-                print(yaml.safe_load(verification[2]))
+                print(yaml.safe_load(verification["trace"]))
             else:
-                print(verification[0])
-                print(verification[1])
-                print(_("\nFor more details run:\nrally -vd task detailed %s")
+                print(verification["etype"])
+                print(verification["msg"])
+                print(_("\nFor more details run:\nrally -d task detailed %s")
                       % task["uuid"])
             return 0
         elif task["status"] not in [consts.TaskStatus.FINISHED,
@@ -350,7 +352,7 @@ class TaskCommands(object):
             print()
 
             iterations = []
-            iterations_headers = ["iteration", "full duration"]
+            iterations_headers = ["iteration", "duration"]
             iterations_actions = []
             output = []
             task_errors = []
@@ -363,8 +365,7 @@ class TaskCommands(object):
             for idx, itr in enumerate(result["iterations"], 1):
 
                 if iterations_data:
-                    row = {"iteration": idx,
-                           "full duration": itr["duration"]}
+                    row = {"iteration": idx, "duration": itr["duration"]}
                     for name, action in iterations_actions:
                         row[action] = itr["atomic_actions"].get(name, 0)
                     iterations.append(row)
@@ -471,6 +472,7 @@ class TaskCommands(object):
 
         results = [{"key": x["key"], "result": x["data"]["raw"],
                     "sla": x["data"]["sla"],
+                    "hooks": x["data"].get("hooks", []),
                     "load_duration": x["data"]["load_duration"],
                     "full_duration": x["data"]["full_duration"]}
                    for x in task.get_results()]
@@ -580,6 +582,7 @@ class TaskCommands(object):
                 task_results = map(
                     lambda x: {"key": x["key"],
                                "sla": x["data"]["sla"],
+                               "hooks": x["data"].get("hooks", []),
                                "result": x["data"]["raw"],
                                "load_duration": x["data"]["load_duration"],
                                "full_duration": x["data"]["full_duration"]},
@@ -659,6 +662,7 @@ class TaskCommands(object):
                 tasks_results = map(
                     lambda x: {"key": x["key"],
                                "sla": x["data"]["sla"],
+                               "hooks": x["data"].get("hooks", []),
                                "result": x["data"]["raw"],
                                "load_duration": x["data"]["load_duration"],
                                "full_duration": x["data"]["full_duration"]},
