@@ -53,8 +53,7 @@ from rally.common.i18n import _
 CONF = cfg.CONF
 
 
-db_options.set_defaults(CONF, connection="sqlite:////tmp/rally.sqlite",
-                        sqlite_db="rally.sqlite")
+db_options.set_defaults(CONF, connection="sqlite:////tmp/rally.sqlite")
 
 
 IMPL = None
@@ -120,11 +119,6 @@ def schema_create():
     return get_impl().schema_create()
 
 
-def schema_downgrade(revision):
-    """Downgrade DB schema to specified revision."""
-    return get_impl().schema_downgrade(revision)
-
-
 def schema_revision():
     """Return the schema revision."""
     return get_impl().schema_revision()
