@@ -82,7 +82,8 @@ OUTPUT_SCHEMA = {
                              }
                          },
                          "required": ["cols", "rows"],
-                         "additionalProperties": False}
+                         "additionalProperties": False},
+                        {"type": "array", "items": {"type": "string"}},
                     ]},
                     "label": {"type": "string"},
                     "axis_label": {"type": "string"}
@@ -96,6 +97,42 @@ OUTPUT_SCHEMA = {
     "additionalProperties": False
 }
 
+HOOK_RUN_RESULT_SCHEMA = {
+    "type": "object",
+    "properties": {
+        "started_at": {"type": "number"},
+        "finished_at": {"type": "number"},
+        "triggered_by": {
+            "type": "object",
+            "properties": {"event_type": {"type": "string"},
+                           "value": {}},
+            "required": ["event_type", "value"],
+            "additionalProperties": False
+        },
+        "status": {"type": "string"},
+        "error": {
+            "type": "array",
+            "minItems": 3,
+            "maxItems": 3,
+            "items": {"type": "string"},
+        },
+        "output": OUTPUT_SCHEMA,
+    },
+    "required": ["finished_at", "triggered_by", "status"],
+    "additionalProperties": False
+}
+
+HOOK_RESULTS_SCHEMA = {
+    "type": "object",
+    "properties": {
+        "config": {"type": "object"},
+        "results": {"type": "array",
+                    "items": HOOK_RUN_RESULT_SCHEMA},
+        "summary": {"type": "object"}
+    },
+    "required": ["config", "results", "summary"],
+    "additionalProperties": False,
+}
 
 TASK_RESULT_SCHEMA = {
     "type": "object",
@@ -133,6 +170,7 @@ TASK_RESULT_SCHEMA = {
                 }
             }
         },
+        "hooks": {"type": "array", "items": HOOK_RESULTS_SCHEMA},
         "result": {
             "type": "array",
             "items": {
@@ -178,8 +216,7 @@ TASK_RESULT_SCHEMA = {
             "type": "number",
         },
     },
-    "required": ["key", "sla", "result", "load_duration",
-                 "full_duration"],
+    "required": ["key", "sla", "result", "load_duration", "full_duration"],
     "additionalProperties": False
 }
 
@@ -220,6 +257,7 @@ TASK_EXTENDED_RESULT_SCHEMA = {
                 }
             }
         },
+        "hooks": {"type": "array", "items": HOOK_RESULTS_SCHEMA},
         "iterations": {
             "type": "array",
             "items": {
@@ -350,10 +388,8 @@ class Task(object):
 
     def set_failed(self, etype, msg, etraceback):
         self._update({"status": consts.TaskStatus.FAILED,
-                      "verification_log": json.dumps([etype,
-                                                      msg,
-                                                      etraceback
-                                                      ])})
+                      "verification_log": json.dumps(
+                          {"etype": etype, "msg": msg, "trace": etraceback})})
 
     def get_results(self):
         return db.task_result_get_all_by_uuid(self.task["uuid"])
@@ -475,6 +511,7 @@ class Task(object):
             else:
                 scenario["iterations"] = iter(iterations)
             scenario["sla"] = scenario["data"]["sla"]
+            scenario["hooks"] = scenario["data"].get("hooks", [])
             del scenario["data"]
             del scenario["task_uuid"]
             del scenario["id"]
