@@ -69,6 +69,7 @@ class FileExporter(exporter.Exporter):
 
         task_results = [{"key": x["key"], "result": x["data"]["raw"],
                          "sla": x["data"]["sla"],
+                         "hooks": x["data"].get("hooks"),
                          "load_duration": x["data"]["load_duration"],
                          "full_duration": x["data"]["full_duration"]}
                         for x in task.get_results()]
@@ -99,6 +100,5 @@ class DeprecatedFileExporter(FileExporter):
     """DEPRECATED."""
     def __init__(self, connection_string):
         super(DeprecatedFileExporter, self).__init__(connection_string)
-        import warnings
-        warnings.warn("'file-exporter' plugin is deprecated. Use 'file' "
-                      "instead.")
+        LOG.warning("'file-exporter' plugin is deprecated. Use 'file' "
+                    "instead.")
