@@ -66,6 +66,42 @@ class QuotaMixin(SynchronizedDeletion):
         return [self.tenant_uuid] if self.tenant_uuid else []
 
 
+# MAGNUM
+
+_magnum_order = get_order(80)
+
+
+@base.resource(service=None, resource=None)
+class MagnumMixin(base.ResourceManager):
+
+    def id(self):
+        """Returns id of resource."""
+        return self.raw_resource.uuid
+
+    def list(self):
+        result = []
+        marker = None
+        while True:
+            resources = self._manager().list(marker=marker)
+            if not resources:
+                break
+            result.extend(resources)
+            marker = resources[-1].uuid
+        return result
+
+
+@base.resource("magnum", "clusters", order=next(_magnum_order),
+               tenant_resource=True)
+class MagnumCluster(MagnumMixin):
+    """Resource class for Magnum cluster."""
+
+
+@base.resource("magnum", "cluster_templates", order=next(_magnum_order),
+               tenant_resource=True)
+class MagnumClusterTemplate(MagnumMixin):
+    """Resource class for Magnum cluster_template."""
+
+
 # HEAT
 
 @base.resource("heat", "stacks", order=100, tenant_resource=True)
@@ -226,6 +262,14 @@ class NovaNetworks(SynchronizedDeletion, base.ResourceManager):
                 if utils.name_matches_object(net.label, *classes)]
 
 
+@base.resource("nova", "aggregates", order=next(_nova_order),
+               admin_required=True, perform_for_admin_only=True)
+class NovaAggregate(SynchronizedDeletion, base.ResourceManager):
+    def list(self):
+        return [r for r in self._manager().list()
+                if utils.name_matches_object(r.name, nova_utils.NovaScenario)]
+
+
 # EC2
 
 _ec2_order = get_order(250)
