@@ -46,6 +46,9 @@ USER_CONTEXT_OPTS = [
     cfg.StrOpt("user_domain",
                default="default",
                help="ID of domain in which users will be created."),
+    cfg.StrOpt("keystone_default_role",
+               default="member",
+               help="The default role name of the keystone."),
 ]
 
 CONF = cfg.CONF
@@ -87,12 +90,15 @@ class UserContextMixin(object):
         else:
             # Second and last case - 'round_robin'.
             tenants_amount = len(context_obj["tenants"])
-            tenant_id = sorted(context_obj["tenants"].keys())[
-                context_obj["iteration"] % tenants_amount]
+            # NOTE(amaretskiy): iteration is subtracted by `1' because it
+            #                   starts from `1' but we count from `0'
+            tenant_index = int((context_obj["iteration"] - 1) % tenants_amount)
+            tenant_id = sorted(context_obj["tenants"].keys())[tenant_index]
             tenant = context_obj["tenants"][tenant_id]
             users = context_obj["tenants"][tenant_id]["users"]
-            user = users[
-                int(context_obj["iteration"] / tenants_amount) % len(users)]
+            user_index = int(((context_obj["iteration"] - 1) / tenants_amount)
+                             % len(users))
+            user = users[user_index]
 
         scenario_ctx["user"], scenario_ctx["tenant"] = user, tenant
 
@@ -223,6 +229,7 @@ class UserGenerator(UserContextMixin, context.Context):
         # NOTE(msdubov): This should be called after _create_tenants().
         threads = self.config["resource_management_workers"]
         users_per_tenant = self.config["users_per_tenant"]
+        default_role = cfg.CONF.users_context.keystone_default_role
 
         users = collections.deque()
 
@@ -241,9 +248,11 @@ class UserGenerator(UserContextMixin, context.Context):
                 clients = osclients.Clients(self.credential)
                 cache["client"] = keystone.wrap(clients.keystone())
             client = cache["client"]
-            user = client.create_user(username, password,
-                                      "%s@email.me" % username,
-                                      tenant_id, user_dom)
+            user = client.create_user(
+                username, password,
+                "%s@email.me" % username,
+                tenant_id, user_dom,
+                default_role=default_role)
             user_credential = objects.Credential(
                 client.auth_url, user.name, password,
                 self.context["tenants"][tenant_id]["name"],
