@@ -19,15 +19,18 @@ from rally.plugins.openstack.scenarios.keystone import utils as kutils
 from rally.task import validation
 
 
-class KeystoneBasic(kutils.KeystoneScenario):
-    """Basic benchmark scenarios for Keystone."""
+"""Benchmark scenarios for Keystone."""
+
+
+@validation.required_openstack(admin=True)
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_user")
+class CreateUser(kutils.KeystoneScenario):
 
-    @validation.required_openstack(admin=True)
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
     @logging.log_deprecated_args(
         "The 'name_length' argument to create_user is ignored",
         "0.1.2", ["name_length"], once=True)
-    def create_user(self, name_length=10, **kwargs):
+    def run(self, name_length=10, **kwargs):
         """Create a keystone user with random name.
 
         :param kwargs: Other optional parameters to create users like
@@ -35,12 +38,16 @@ class KeystoneBasic(kutils.KeystoneScenario):
         """
         self._user_create(**kwargs)
 
-    @validation.required_openstack(admin=True)
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
+
+@validation.required_openstack(admin=True)
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_delete_user")
+class CreateDeleteUser(kutils.KeystoneScenario):
+
     @logging.log_deprecated_args(
         "The 'name_length' argument to create_delete_user is ignored",
         "0.1.2", ["name_length"], once=True)
-    def create_delete_user(self, name_length=10, **kwargs):
+    def run(self, name_length=10, **kwargs):
         """Create a keystone user with random name and then delete it.
 
         :param kwargs: Other optional parameters to create users like
@@ -49,9 +56,13 @@ class KeystoneBasic(kutils.KeystoneScenario):
         user = self._user_create(**kwargs)
         self._resource_delete(user)
 
-    @validation.required_openstack(admin=True)
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
-    def create_user_set_enabled_and_delete(self, enabled=True, **kwargs):
+
+@validation.required_openstack(admin=True)
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_user_set_enabled_and_delete")
+class CreateUserSetEnabledAndDelete(kutils.KeystoneScenario):
+
+    def run(self, enabled=True, **kwargs):
         """Create a keystone user, enable or disable it, and delete it.
 
         :param enabled: Initial state of user 'enabled' flag. The user
@@ -63,28 +74,53 @@ class KeystoneBasic(kutils.KeystoneScenario):
         self._update_user_enabled(user, not enabled)
         self._resource_delete(user)
 
-    @validation.required_openstack(admin=True)
-    @validation.required_api_versions(component="keystone", versions=[2.0])
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
+
+@validation.required_openstack(admin=True)
+@validation.required_api_versions(component="keystone", versions=[2.0])
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_tenant")
+class CreateTenant(kutils.KeystoneScenario):
+
     @logging.log_deprecated_args(
         "The 'name_length' argument to create_tenant is ignored",
         "0.1.2", ["name_length"], once=True)
-    def create_tenant(self, name_length=10, **kwargs):
+    def run(self, name_length=10, **kwargs):
         """Create a keystone tenant with random name.
 
         :param kwargs: Other optional parameters
         """
         self._tenant_create(**kwargs)
 
-    @validation.number("users_per_tenant", minval=1)
-    @validation.required_openstack(admin=True)
-    @validation.required_api_versions(component="keystone", versions=[2.0])
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
+
+@validation.required_openstack(admin=True)
+@validation.required_api_versions(component="keystone", versions=[2.0])
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.authenticate_user_and_validate_token")
+class AuthenticateUserAndValidateToken(kutils.KeystoneScenario):
+
+    def run(self):
+        """Authenticate and validate a keystone token."""
+        name = self.context["user"]["credential"].username
+        password = self.context["user"]["credential"].password
+        tenant_id = self.context["tenant"]["id"]
+        tenant_name = self.context["tenant"]["name"]
+
+        token = self._authenticate_token(name, password, tenant_id,
+                                         tenant_name, atomic_action=False)
+        self._token_validate(token.id)
+
+
+@validation.number("users_per_tenant", minval=1)
+@validation.required_openstack(admin=True)
+@validation.required_api_versions(component="keystone", versions=[2.0])
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_tenant_with_users")
+class CreateTenantWithUsers(kutils.KeystoneScenario):
+
     @logging.log_deprecated_args(
         "The 'name_length' argument to create_tenant_with_users is ignored",
         "0.1.2", ["name_length"], once=True)
-    def create_tenant_with_users(self, users_per_tenant, name_length=10,
-                                 **kwargs):
+    def run(self, users_per_tenant, name_length=10, **kwargs):
         """Create a keystone tenant and several users belonging to it.
 
         :param users_per_tenant: number of users to create for the tenant
@@ -94,12 +130,16 @@ class KeystoneBasic(kutils.KeystoneScenario):
         tenant = self._tenant_create(**kwargs)
         self._users_create(tenant, users_per_tenant=users_per_tenant)
 
-    @validation.required_openstack(admin=True)
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
+
+@validation.required_openstack(admin=True)
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_and_list_users")
+class CreateAndListUsers(kutils.KeystoneScenario):
+
     @logging.log_deprecated_args(
         "The 'name_length' argument to create_and_list_users is ignored",
         "0.1.2", ["name_length"], once=True)
-    def create_and_list_users(self, name_length=10, **kwargs):
+    def run(self, name_length=10, **kwargs):
         """Create a keystone user with random name and list all users.
 
         :param kwargs: Other optional parameters to create users like
@@ -108,13 +148,17 @@ class KeystoneBasic(kutils.KeystoneScenario):
         self._user_create(**kwargs)
         self._list_users()
 
-    @validation.required_openstack(admin=True)
-    @validation.required_api_versions(component="keystone", versions=[2.0])
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
+
+@validation.required_openstack(admin=True)
+@validation.required_api_versions(component="keystone", versions=[2.0])
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_and_list_tenants")
+class CreateAndListTenants(kutils.KeystoneScenario):
+
     @logging.log_deprecated_args(
         "The 'name_length' argument to create_and_list_tenants is ignored",
         "0.1.2", ["name_length"], once=True)
-    def create_and_list_tenants(self, name_length=10, **kwargs):
+    def run(self, name_length=10, **kwargs):
         """Create a keystone tenant with random name and list all tenants.
 
         :param kwargs: Other optional parameters
@@ -122,9 +166,13 @@ class KeystoneBasic(kutils.KeystoneScenario):
         self._tenant_create(**kwargs)
         self._list_tenants()
 
-    @validation.required_openstack(admin=True, users=True)
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
-    def add_and_remove_user_role(self):
+
+@validation.required_openstack(admin=True, users=True)
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.add_and_remove_user_role")
+class AddAndRemoveUserRole(kutils.KeystoneScenario):
+
+    def run(self):
         """Create a user role add to a user and disassociate."""
         tenant_id = self.context["tenant"]["id"]
         user_id = self.context["user"]["id"]
@@ -132,16 +180,24 @@ class KeystoneBasic(kutils.KeystoneScenario):
         self._role_add(user_id, role, tenant_id)
         self._role_remove(user_id, role, tenant_id)
 
-    @validation.required_openstack(admin=True)
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
-    def create_and_delete_role(self):
+
+@validation.required_openstack(admin=True)
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_and_delete_role")
+class CreateAndDeleteRole(kutils.KeystoneScenario):
+
+    def run(self):
         """Create a user role and delete it."""
         role = self._role_create()
         self._resource_delete(role)
 
-    @validation.required_openstack(admin=True, users=True)
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
-    def create_add_and_list_user_roles(self):
+
+@validation.required_openstack(admin=True, users=True)
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_add_and_list_user_roles")
+class CreateAddAndListUserRoles(kutils.KeystoneScenario):
+
+    def run(self):
         """Create user role, add it and list user roles for given user."""
         tenant_id = self.context["tenant"]["id"]
         user_id = self.context["user"]["id"]
@@ -149,10 +205,14 @@ class KeystoneBasic(kutils.KeystoneScenario):
         self._role_add(user_id, role, tenant_id)
         self._list_roles_for_user(user_id, tenant_id)
 
-    @validation.required_openstack(admin=True)
-    @validation.required_api_versions(component="keystone", versions=[2.0])
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
-    def get_entities(self, service_name="keystone"):
+
+@validation.required_openstack(admin=True)
+@validation.required_api_versions(component="keystone", versions=[2.0])
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.get_entities")
+class GetEntities(kutils.KeystoneScenario):
+
+    def run(self, service_name="keystone"):
         """Get instance of a tenant, user, role and service by id's.
 
         An ephemeral tenant, user, and role are each created. By
@@ -178,13 +238,16 @@ class KeystoneBasic(kutils.KeystoneScenario):
             service = self._get_service_by_name(service_name)
         self._get_service(service.id)
 
-    @validation.required_openstack(admin=True)
+
+@validation.required_openstack(admin=True)
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_and_delete_service")
+class CreateAndDeleteService(kutils.KeystoneScenario):
+
     @logging.log_deprecated_args(
         "The 'name' argument to create_and_delete_service will be ignored",
         "0.0.5", ["name"])
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
-    def create_and_delete_service(self, name=None, service_type=None,
-                                  description=None):
+    def run(self, name=None, service_type=None, description=None):
         """Create and delete service.
 
         :param service_type: type of the service
@@ -193,13 +256,17 @@ class KeystoneBasic(kutils.KeystoneScenario):
         service = self._service_create(service_type, description)
         self._delete_service(service.id)
 
-    @validation.required_openstack(admin=True)
-    @validation.required_api_versions(component="keystone", versions=[2.0])
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
+
+@validation.required_openstack(admin=True)
+@validation.required_api_versions(component="keystone", versions=[2.0])
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_update_and_delete_tenant")
+class CreateUpdateAndDeleteTenant(kutils.KeystoneScenario):
+
     @logging.log_deprecated_args(
         "The 'name_length' argument to create_update_and_delete_tenant is "
         "ignored", "0.1.2", ["name_length"], once=True)
-    def create_update_and_delete_tenant(self, name_length=None, **kwargs):
+    def run(self, name_length=None, **kwargs):
         """Create, update and delete tenant.
 
         :param kwargs: Other optional parameters for tenant creation
@@ -208,26 +275,32 @@ class KeystoneBasic(kutils.KeystoneScenario):
         self._update_tenant(tenant)
         self._resource_delete(tenant)
 
-    @validation.required_openstack(admin=True)
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
+
+@validation.required_openstack(admin=True)
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_user_update_password")
+class CreateUserUpdatePassword(kutils.KeystoneScenario):
+
     @logging.log_deprecated_args(
         "The 'name_length' and 'password_length' arguments to "
         "create_user_update_password are ignored",
         "0.1.2", ["name_length", "password_length"], once=True)
-    def create_user_update_password(self, name_length=None,
-                                    password_length=None):
+    def run(self, name_length=None, password_length=None):
         """Create user and update password for that user."""
         password = self.generate_random_name()
         user = self._user_create()
         self._update_user_password(user.id, password)
 
-    @validation.required_openstack(admin=True)
+
+@validation.required_openstack(admin=True)
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_and_list_services")
+class CreateAndListServices(kutils.KeystoneScenario):
+
     @logging.log_deprecated_args(
         "The 'name' argument to create_and_list_services will be ignored",
         "0.0.5", ["name"])
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
-    def create_and_list_services(self, name=None, service_type=None,
-                                 description=None):
+    def run(self, name=None, service_type=None, description=None):
         """Create and list services.
 
         :param service_type: type of the service
@@ -236,17 +309,25 @@ class KeystoneBasic(kutils.KeystoneScenario):
         self._service_create(service_type, description)
         self._list_services()
 
-    @validation.required_openstack(users=True)
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
-    def create_and_list_ec2credentials(self):
+
+@validation.required_openstack(users=True)
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_and_list_ec2credentials")
+class CreateAndListEc2Credentials(kutils.KeystoneScenario):
+
+    def run(self):
         """Create and List all keystone ec2-credentials."""
         self._create_ec2credentials(self.context["user"]["id"],
                                     self.context["tenant"]["id"])
         self._list_ec2credentials(self.context["user"]["id"])
 
-    @validation.required_openstack(users=True)
-    @scenario.configure(context={"admin_cleanup": ["keystone"]})
-    def create_and_delete_ec2credential(self):
+
+@validation.required_openstack(users=True)
+@scenario.configure(context={"admin_cleanup": ["keystone"]},
+                    name="KeystoneBasic.create_and_delete_ec2credential")
+class CreateAndDeleteEc2Credential(kutils.KeystoneScenario):
+
+    def run(self):
         """Create and delete keystone ec2-credential."""
         creds = self._create_ec2credentials(self.context["user"]["id"],
                                             self.context["tenant"]["id"])
