@@ -14,7 +14,6 @@
 #    under the License.
 
 import random
-import time
 
 from oslo_config import cfg
 import six
@@ -139,7 +138,7 @@ class NovaScenario(scenario.OpenStackScenario):
         server = self.clients("nova").servers.create(
             server_name, image_id, flavor_id, **kwargs)
 
-        time.sleep(CONF.benchmark.nova_server_boot_prepoll_delay)
+        self.sleep_between(CONF.benchmark.nova_server_boot_prepoll_delay)
         server = utils.wait_for(
             server,
             ready_statuses=["ACTIVE"],
@@ -151,7 +150,7 @@ class NovaScenario(scenario.OpenStackScenario):
 
     def _do_server_reboot(self, server, reboottype):
         server.reboot(reboot_type=reboottype)
-        time.sleep(CONF.benchmark.nova_server_reboot_prepoll_delay)
+        self.sleep_between(CONF.benchmark.nova_server_pause_prepoll_delay)
         utils.wait_for(
             server,
             ready_statuses=["ACTIVE"],
@@ -213,7 +212,7 @@ class NovaScenario(scenario.OpenStackScenario):
         :param kwargs: Optional additional arguments to pass to the rebuild
         """
         server.rebuild(image, **kwargs)
-        time.sleep(CONF.benchmark.nova_server_rebuild_prepoll_delay)
+        self.sleep_between(CONF.benchmark.nova_server_rebuild_prepoll_delay)
         utils.wait_for(
             server,
             ready_statuses=["ACTIVE"],
@@ -268,7 +267,7 @@ class NovaScenario(scenario.OpenStackScenario):
         :param server: Server object
         """
         server.rescue()
-        time.sleep(CONF.benchmark.nova_server_rescue_prepoll_delay)
+        self.sleep_between(CONF.benchmark.nova_server_rescue_prepoll_delay)
         utils.wait_for(
             server,
             ready_statuses=["RESCUE"],
@@ -286,7 +285,7 @@ class NovaScenario(scenario.OpenStackScenario):
         :param server: Server object
         """
         server.unrescue()
-        time.sleep(CONF.benchmark.nova_server_unrescue_prepoll_delay)
+        self.sleep_between(CONF.benchmark.nova_server_unrescue_prepoll_delay)
         utils.wait_for(
             server,
             ready_statuses=["ACTIVE"],
@@ -305,7 +304,7 @@ class NovaScenario(scenario.OpenStackScenario):
         :param server: Server object
         """
         server.suspend()
-        time.sleep(CONF.benchmark.nova_server_suspend_prepoll_delay)
+        self.sleep_between(CONF.benchmark.nova_server_suspend_prepoll_delay)
         utils.wait_for(
             server,
             ready_statuses=["SUSPENDED"],
@@ -324,7 +323,7 @@ class NovaScenario(scenario.OpenStackScenario):
         :param server: Server object
         """
         server.resume()
-        time.sleep(CONF.benchmark.nova_server_resume_prepoll_delay)
+        self.sleep_between(CONF.benchmark.nova_server_resume_prepoll_delay)
         utils.wait_for(
             server,
             ready_statuses=["ACTIVE"],
@@ -343,7 +342,7 @@ class NovaScenario(scenario.OpenStackScenario):
         :param server: Server object
         """
         server.pause()
-        time.sleep(CONF.benchmark.nova_server_pause_prepoll_delay)
+        self.sleep_between(CONF.benchmark.nova_server_pause_prepoll_delay)
         utils.wait_for(
             server,
             ready_statuses=["PAUSED"],
@@ -362,7 +361,7 @@ class NovaScenario(scenario.OpenStackScenario):
         :param server: Server object
         """
         server.unpause()
-        time.sleep(CONF.benchmark.nova_server_unpause_prepoll_delay)
+        self.sleep_between(CONF.benchmark.nova_server_pause_prepoll_delay)
         utils.wait_for(
             server,
             ready_statuses=["ACTIVE"],
@@ -381,7 +380,7 @@ class NovaScenario(scenario.OpenStackScenario):
         :param server: Server object
         """
         server.shelve()
-        time.sleep(CONF.benchmark.nova_server_shelve_prepoll_delay)
+        self.sleep_between(CONF.benchmark.nova_server_pause_prepoll_delay)
         utils.wait_for(
             server,
             ready_statuses=["SHELVED_OFFLOADED"],
@@ -399,7 +398,8 @@ class NovaScenario(scenario.OpenStackScenario):
         :param server: Server object
         """
         server.unshelve()
-        time.sleep(CONF.benchmark.nova_server_unshelve_prepoll_delay)
+
+        self.sleep_between(CONF.benchmark. nova_server_unshelve_prepoll_delay)
         utils.wait_for(
             server,
             ready_statuses=["ACTIVE"],
@@ -570,7 +570,7 @@ class NovaScenario(scenario.OpenStackScenario):
         #                created servers manually.
         servers = [s for s in self.clients("nova").servers.list()
                    if s.name.startswith(name_prefix)]
-        time.sleep(CONF.benchmark.nova_server_boot_prepoll_delay)
+        self.sleep_between(CONF.benchmark.nova_server_boot_prepoll_delay)
         servers = [utils.wait_for(
             server,
             ready_statuses=["ACTIVE"],
@@ -863,6 +863,18 @@ class NovaScenario(scenario.OpenStackScenario):
         """List hypervisors."""
         return self.admin_clients("nova").hypervisors.list(detailed)
 
+    @atomic.optional_action_timer("nova.get_hypervisor")
+    def _get_hypervisor(self, hypervisor):
+        """Get a specific hypervisor.
+
+        :param hypervisor: Hypervisor to get.
+        :param atomic_action: True if this is atomic action. added and
+                              handled by the optional_action_timer()
+                              decorator.
+        :returns: Hypervisor object
+        """
+        return self.admin_clients("nova").hypervisors.get(hypervisor)
+
     @atomic.action_timer("nova.lock_server")
     def _lock_server(self, server):
         """Lock the given server.
@@ -909,6 +921,15 @@ class NovaScenario(scenario.OpenStackScenario):
         """
         return self.clients("nova").flavors.list(detailed, **kwargs)
 
+    @atomic.action_timer("nova.set_flavor_keys")
+    def _set_flavor_keys(self, flavor, extra_specs):
+        """set flavor keys
+
+        :param flavor: flavor to set keys
+        :param extra_specs: additional arguments for flavor set keys
+        """
+        return flavor.set_keys(extra_specs)
+
     @atomic.action_timer("nova.list_agents")
     def _list_agents(self, hypervisor=None):
         """List all nova-agent builds.
@@ -987,3 +1008,183 @@ class NovaScenario(scenario.OpenStackScenario):
                                  description=description)
         else:
             return server.update(name=new_name)
+
+    @atomic.action_timer("nova.get_flavor")
+    def _get_flavor(self, flavor_id):
+        """Show a flavor
+
+        :param flavor_id: The flavor ID to get
+        """
+        return self.admin_clients("nova").flavors.get(flavor_id)
+
+    @atomic.action_timer("nova.create_aggregate")
+    def _create_aggregate(self, availability_zone):
+        """Create a new aggregate.
+
+        :param availability_zone: The availability zone of the aggregate
+        :returns: The created aggregate
+        """
+        aggregate_name = self.generate_random_name()
+        return self.admin_clients("nova").aggregates.create(aggregate_name,
+                                                            availability_zone)
+
+    @atomic.action_timer("nova.delete_aggregate")
+    def _delete_aggregate(self, aggregate):
+        """Delete the specified aggregate.
+
+        :param aggregate: The aggregate to delete
+        :returns: An instance of novaclient.base.TupleWithMeta
+        """
+        return self.admin_clients("nova").aggregates.delete(aggregate)
+
+    @atomic.action_timer("nova.bind_actions")
+    def _bind_actions(self):
+        actions = ["hard_reboot", "soft_reboot", "stop_start",
+                   "rescue_unrescue", "pause_unpause", "suspend_resume",
+                   "lock_unlock", "shelve_unshelve"]
+        action_builder = utils.ActionBuilder(actions)
+        action_builder.bind_action("hard_reboot", self._reboot_server)
+        action_builder.bind_action("soft_reboot", self._soft_reboot_server)
+        action_builder.bind_action("stop_start",
+                                   self._stop_and_start_server)
+        action_builder.bind_action("rescue_unrescue",
+                                   self._rescue_and_unrescue_server)
+        action_builder.bind_action("pause_unpause",
+                                   self._pause_and_unpause_server)
+        action_builder.bind_action("suspend_resume",
+                                   self._suspend_and_resume_server)
+        action_builder.bind_action("lock_unlock",
+                                   self._lock_and_unlock_server)
+        action_builder.bind_action("shelve_unshelve",
+                                   self._shelve_and_unshelve_server)
+
+        return action_builder
+
+    @atomic.action_timer("nova.stop_and_start_server")
+    def _stop_and_start_server(self, server):
+        """Stop and then start the given server.
+
+        A stop will be issued on the given server upon which time
+        this method will wait for the server to become 'SHUTOFF'.
+        Once the server is SHUTOFF a start will be issued and this
+        method will wait for the server to become 'ACTIVE' again.
+
+        :param server: The server to stop and then start.
+
+        """
+        self._stop_server(server)
+        self._start_server(server)
+
+    @atomic.action_timer("nova.rescue_and_unrescue_server")
+    def _rescue_and_unrescue_server(self, server):
+        """Rescue and then unrescue the given server.
+
+        A rescue will be issued on the given server upon which time
+        this method will wait for the server to become 'RESCUE'.
+        Once the server is RESCUE an unrescue will be issued and
+        this method will wait for the server to become 'ACTIVE'
+        again.
+
+        :param server: The server to rescue and then unrescue.
+
+        """
+        self._rescue_server(server)
+        self._unrescue_server(server)
+
+    @atomic.action_timer("nova.pause_and_unpause_server")
+    def _pause_and_unpause_server(self, server):
+        """Pause and then unpause the given server.
+
+        A pause will be issued on the given server upon which time
+        this method will wait for the server to become 'PAUSED'.
+        Once the server is PAUSED an unpause will be issued and
+        this method will wait for the server to become 'ACTIVE'
+        again.
+
+        :param server: The server to pause and then unpause.
+
+        """
+        self._pause_server(server)
+        self._unpause_server(server)
+
+    @atomic.action_timer("nova.suspend_and_resume_server")
+    def _suspend_and_resume_server(self, server):
+        """Suspend and then resume the given server.
+
+        A suspend will be issued on the given server upon which time
+        this method will wait for the server to become 'SUSPENDED'.
+        Once the server is SUSPENDED an resume will be issued and
+        this method will wait for the server to become 'ACTIVE'
+        again.
+
+        :param server: The server to suspend and then resume.
+
+        """
+        self._suspend_server(server)
+        self._resume_server(server)
+
+    @atomic.action_timer("nova.lock_and_unlock_server")
+    def _lock_and_unlock_server(self, server):
+        """Lock and then unlock the given server.
+
+        A lock will be issued on the given server upon which time
+        this method will wait for the server to become locked'.
+        Once the server is locked an unlock will be issued.
+
+        :param server: The server to lock and then unlock.
+
+        """
+        self._lock_server(server)
+        self._unlock_server(server)
+
+    @atomic.action_timer("nova.shelve_and_unshelve_server")
+    def _shelve_and_unshelve_server(self, server):
+        """Shelve and then unshelve the given server.
+
+        A shelve will be issued on the given server upon which time
+        this method will wait for the server to become 'SHELVED'.
+        Once the server is SHELVED an unshelve will be issued and
+        this method will wait for the server to become 'ACTIVE'
+        again.
+
+        :param server: The server to shelve and then unshelve.
+
+        """
+        self._shelve_server(server)
+        self._unshelve_server(server)
+
+    @atomic.action_timer("nova.update_aggregate")
+    def _update_aggregate(self, aggregate):
+        """Update the aggregate's name and availability_zone.
+
+        :param aggregate: The aggregate to update
+        :return: The updated aggregate
+        """
+        aggregate_name = self.generate_random_name()
+        availability_zone = self.generate_random_name()
+        values = {"name": aggregate_name,
+                  "availability_zone": availability_zone}
+        return self.admin_clients("nova").aggregates.update(aggregate,
+                                                            values)
+
+    @atomic.action_timer("nova.aggregate_add_host")
+    def _aggregate_add_host(self, aggregate, host):
+        """Add a host into the Host Aggregate.
+
+        :param aggregate: The aggregate add host to
+        :param host: The host add to aggregate
+        :returns: The aggregate that has been added host to
+        """
+        return self.admin_clients("nova").aggregates.add_host(aggregate,
+                                                              host)
+
+    @atomic.action_timer("nova.aggregate_remove_host")
+    def _aggregate_remove_host(self, aggregate, host):
+        """Remove a host from an aggregate.
+
+        :param aggregate: The aggregate remove host from
+        :param host: The host to remove
+        :returns: The aggregate that has been removed host from
+        """
+        return self.admin_clients("nova").aggregates.remove_host(aggregate,
+                                                                 host)
