@@ -14,6 +14,7 @@
 #    under the License.
 
 import collections
+import datetime as dt
 import hashlib
 import json
 
@@ -26,6 +27,61 @@ from rally.task.processing import charts
 from rally.ui import utils as ui_utils
 
 
+def _process_hooks(hooks):
+    """Prepare hooks data for report."""
+    hooks_ctx = []
+    for hook in hooks:
+        hook_ctx = {"name": hook["config"]["name"],
+                    "desc": hook["config"]["description"],
+                    "additive": [], "complete": []}
+
+        for res in hook["results"]:
+            started_at = dt.datetime.utcfromtimestamp(res["started_at"])
+            finished_at = dt.datetime.utcfromtimestamp(res["finished_at"])
+            triggered_by = "%(event_type)s: %(value)s" % res["triggered_by"]
+
+            for i, data in enumerate(res.get("output", {}).get("additive")):
+                try:
+                    hook_ctx["additive"][i]
+                except IndexError:
+                    chart_cls = plugin.Plugin.get(data["chart_plugin"])
+                    hook_ctx["additive"].append([chart_cls])
+                hook_ctx["additive"][i].append(data)
+
+            complete_charts = []
+            for data in res.get("output", {}).get("complete"):
+                chart_cls = plugin.Plugin.get(data.pop("chart_plugin"))
+                data["widget"] = chart_cls.widget
+                complete_charts.append(data)
+
+            if complete_charts:
+                hook_ctx["complete"].append(
+                    {"triggered_by": triggered_by,
+                     "started_at": started_at.strftime("%Y-%m-%d %H:%M:%S"),
+                     "finished_at": finished_at.strftime("%Y-%m-%d %H:%M:%S"),
+                     "status": res["status"],
+                     "charts": complete_charts})
+
+        for i in range(len(hook_ctx["additive"])):
+            chart_cls = hook_ctx["additive"][i].pop(0)
+            iters_count = len(hook_ctx["additive"][i])
+            first = hook_ctx["additive"][i][0]
+            descr = first.get("description", "")
+            axis_label = first.get("axis_label", "")
+            chart = chart_cls({"iterations_count": iters_count},
+                              title=first["title"],
+                              description=descr,
+                              label=first.get("label", ""),
+                              axis_label=axis_label)
+            for data in hook_ctx["additive"][i]:
+                chart.add_iteration(data["data"])
+            hook_ctx["additive"][i] = chart.render()
+
+        if hook_ctx["additive"] or hook_ctx["complete"]:
+            hooks_ctx.append(hook_ctx)
+    return hooks_ctx
+
+
 def _process_scenario(data, pos):
     main_area = charts.MainStackedAreaChart(data["info"])
     main_hist = charts.MainHistogramChart(data["info"])
@@ -75,6 +131,7 @@ def _process_scenario(data, pos):
     cls, method = data["key"]["name"].split(".")
     additive_output = [chart.render() for chart in additive_output_charts]
     iterations_count = data["info"]["iterations_count"]
+
     return {
         "cls": cls,
         "met": method,
@@ -82,6 +139,7 @@ def _process_scenario(data, pos):
         "name": method + (pos and " [%d]" % (pos + 1) or ""),
         "runner": kw["runner"]["type"],
         "config": json.dumps({data["key"]["name"]: [kw]}, indent=2),
+        "hooks": _process_hooks(data["hooks"]),
         "iterations": {
             "iter": main_area.render(),
             "pie": [("success", (data["info"]["iterations_count"]
@@ -95,6 +153,7 @@ def _process_scenario(data, pos):
         "table": main_stat.render(),
         "additive_output": additive_output,
         "complete_output": complete_output,
+        "has_output": any(additive_output) or any(complete_output),
         "output_errors": output_errors,
         "errors": errors,
         "load_duration": data["info"]["load_duration"],
@@ -137,6 +196,7 @@ def _extend_results(results):
                    "task_uuid": None,
                    "key": result["key"],
                    "data": {"sla": result["sla"],
+                            "hooks": result.get("hooks"),
                             "raw": result["result"],
                             "full_duration": result["full_duration"],
                             "load_duration": result["load_duration"]},
@@ -167,15 +227,15 @@ def trends(tasks_results):
 
 
 class Trends(object):
-    """Process tasks results and make trends data.
+    """Process workloads results and make trends data.
 
-    Group tasks results by their input configuration,
+    Group workloads results by their input configuration,
     calculate statistics for these groups and prepare it
     for displaying in trends HTML report.
     """
 
     def __init__(self):
-        self._tasks = {}
+        self._data = {}
 
     def _to_str(self, obj):
         """Convert object into string."""
@@ -197,29 +257,39 @@ class Trends(object):
 
     def add_result(self, result):
         key = self._make_hash(result["key"]["kw"])
-        if key not in self._tasks:
-            name = result["key"]["name"]
-            self._tasks[key] = {"seq": 1,
-                                "name": name,
-                                "cls": name.split(".")[0],
-                                "met": name.split(".")[1],
-                                "data": {},
-                                "total": None,
-                                "atomic": [],
-                                "stat": {},
-                                "sla_failures": 0,
-                                "config": json.dumps(result["key"]["kw"],
-                                                     indent=2)}
-        else:
-            self._tasks[key]["seq"] += 1
+        if key not in self._data:
+            self._data[key] = {
+                "actions": {},
+                "sla_failures": 0,
+                "name": result["key"]["name"],
+                "config": json.dumps(result["key"]["kw"], indent=2)}
 
         for sla in result["sla"]:
-            self._tasks[key]["sla_failures"] += not sla["success"]
+            self._data[key]["sla_failures"] += not sla["success"]
 
-        task = {row[0]: dict(zip(result["info"]["stat"]["cols"], row))
+        stat = {row[0]: dict(zip(result["info"]["stat"]["cols"], row))
                 for row in result["info"]["stat"]["rows"]}
+        ts = int(result["info"]["tstamp_start"] * 1000)
+
+        for action in stat:
+            # NOTE(amaretskiy): some atomic actions can be missed due to
+            #   failures. We can ignore that because we use NVD3 lineChart()
+            #   for displaying trends, which is safe for missed points
+            if action not in self._data[key]["actions"]:
+                self._data[key]["actions"][action] = {
+                    "durations": {"min": [], "median": [], "90%ile": [],
+                                  "95%ile": [], "max": [], "avg": []},
+                    "success": []}
+
+            try:
+                success = float(stat[action]["Success"].rstrip("%"))
+            except ValueError:
+                # Got "n/a" for some reason
+                success = 0
+
+            self._data[key]["actions"][action]["success"].append(
+                (ts, success))
 
-        for k in task:
             for tgt, src in (("min", "Min (sec)"),
                              ("median", "Median (sec)"),
                              ("90%ile", "90%ile (sec)"),
@@ -227,49 +297,44 @@ class Trends(object):
                              ("max", "Max (sec)"),
                              ("avg", "Avg (sec)")):
 
-                # NOTE(amaretskiy): some atomic actions can be
-                #   missed due to failures. We can ignore that
-                #   because we use NVD3 lineChart() for displaying
-                #   trends, which is safe for missed points
-                if k not in self._tasks[key]["data"]:
-                    self._tasks[key]["data"][k] = {"min": [],
-                                                   "median": [],
-                                                   "90%ile": [],
-                                                   "95%ile": [],
-                                                   "max": [],
-                                                   "avg": [],
-                                                   "success": []}
-                self._tasks[key]["data"][k][tgt].append(
-                    (self._tasks[key]["seq"], task[k][src]))
-
-            try:
-                success = float(task[k]["Success"].rstrip("%"))
-            except ValueError:
-                # Got "n/a" for some reason
-                success = 0
-            self._tasks[key]["data"][k]["success"].append(
-                (self._tasks[key]["seq"], success))
+                self._data[key]["actions"][action]["durations"][tgt].append(
+                    (ts, stat[action][src]))
 
     def get_data(self):
-        for key, value in self._tasks.items():
-            total = None
-            for k, v in value["data"].items():
-                success = [("success", v.pop("success"))]
-                if k == "total":
-                    total = {"values": v, "success": success}
+        trends = []
+
+        for wload in self._data.values():
+            trend = {"stat": {},
+                     "name": wload["name"],
+                     "cls": wload["name"].split(".")[0],
+                     "met": wload["name"].split(".")[1],
+                     "sla_failures": wload["sla_failures"],
+                     "config": wload["config"],
+                     "actions": []}
+
+            for action, data in wload["actions"].items():
+                action_durs = [(k, sorted(v))
+                               for k, v in data["durations"].items()]
+                if action == "total":
+                    trend.update(
+                        {"length": len(data["success"]),
+                         "durations": action_durs,
+                         "success": [("success", sorted(data["success"]))]})
                 else:
-                    self._tasks[key]["atomic"].append(
-                        {"name": k, "values": list(v.items()),
-                         "success": success})
+                    trend["actions"].append(
+                        {"name": action,
+                         "durations": action_durs,
+                         "success": [("success", sorted(data["success"]))]})
+
             for stat, comp in (("min", charts.streaming.MinComputation()),
                                ("max", charts.streaming.MaxComputation()),
                                ("avg", charts.streaming.MeanComputation())):
-                for k, v in total["values"][stat]:
-                    if isinstance(v, (float,) + six.integer_types):
-                        comp.add(v)
-                self._tasks[key]["stat"][stat] = comp.result()
-            del self._tasks[key]["data"]
-            total["values"] = list(total["values"].items())
-            self._tasks[key]["total"] = total
-            self._tasks[key]["single"] = self._tasks[key]["seq"] < 2
-        return sorted(self._tasks.values(), key=lambda s: s["name"])
+                for k, v in trend["durations"]:
+                    for i in v:
+                        if isinstance(i[1], (float,) + six.integer_types):
+                            comp.add(i[1])
+                trend["stat"][stat] = comp.result()
+
+            trends.append(trend)
+
+        return sorted(trends, key=lambda i: i["name"])
