@@ -1027,3 +1027,181 @@ class SLAPerfDegrTestCase(unittest.TestCase):
         ]
         data = rally("task sla_check --json", getjson=True)
         self.assertEqual(expected, data)
+
+
+class HookTestCase(unittest.TestCase):
+
+    def setUp(self):
+        super(HookTestCase, self).setUp()
+        self.started = time.time()
+
+    def _assert_results_time(self, results):
+        for trigger_results in results:
+            for result in trigger_results["results"]:
+                started_at = result["started_at"]
+                finished_at = result["finished_at"]
+                self.assertIsInstance(started_at, float)
+                self.assertGreater(started_at, self.started)
+                self.assertIsInstance(finished_at, float)
+                self.assertGreater(finished_at, self.started)
+                self.assertGreater(finished_at, started_at)
+
+    def _get_sample_task_config(self, cmd, description, runner):
+        return {
+            "Dummy.dummy": [
+                {
+                    "args": {
+                        "sleep": 0.1,
+                    },
+                    "runner": runner,
+                    "hooks": [
+                        {
+                            "name": "sys_call",
+                            "description": description,
+                            "args": cmd,
+                            "trigger": {
+                                "name": "event",
+                                "args": {
+                                    "unit": "iteration",
+                                    "at": [5],
+                                }
+                            }
+                        }
+                    ]
+                }
+            ]
+        }
+
+    def _get_result(self, config, iterations=None, seconds=None, error=False):
+        result = {"config": config, "results": [], "summary": {}}
+        events = iterations if iterations else seconds
+        event_type = "iteration" if iterations else "time"
+        status = "failed" if error else "success"
+        for i in range(len(events)):
+            itr_result = {
+                "finished_at": mock.ANY,
+                "started_at": mock.ANY,
+                "triggered_by": {"event_type": event_type, "value": events[i]},
+                "status": status,
+                "output": {
+                    "additive": [],
+                    "complete": [{"chart_plugin": "TextArea",
+                                  "data": ["RetCode: %i" % error,
+                                           "StdOut: (empty)",
+                                           "StdErr: (empty)"],
+                                  "description": "Args: %s" % config["args"],
+                                  "title": "System call"}]}}
+            if error:
+                itr_result["error"] = {"etype": "n/a",
+                                       "msg": "Subprocess returned 1",
+                                       "details": "stdout: "}
+            result["results"].append(itr_result)
+        result["summary"][status] = len(events)
+        return result
+
+    def test_hook_result_with_constant_runner(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config(
+            cmd="/bin/true",
+            description="event_hook",
+            runner={"type": "constant", "times": 10, "concurrency": 3})
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        results = json.loads(rally("task results"))
+        hook_results = results[0]["hooks"]
+        hooks_cfg = cfg["Dummy.dummy"][0]["hooks"]
+        expected = [self._get_result(hooks_cfg[0], iterations=[5])]
+        self.assertEqual(expected, hook_results)
+        self._assert_results_time(hook_results)
+
+    def test_hook_result_with_constant_for_duration_runner(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config(
+            cmd="/bin/true",
+            description="event_hook",
+            runner={"type": "constant_for_duration",
+                    "concurrency": 3, "duration": 10})
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        results = json.loads(rally("task results"))
+        hook_results = results[0]["hooks"]
+        hooks_cfg = cfg["Dummy.dummy"][0]["hooks"]
+        expected = [self._get_result(hooks_cfg[0], iterations=[5])]
+        self.assertEqual(expected, hook_results)
+        self._assert_results_time(hook_results)
+
+    def test_hook_result_with_rps_runner(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config(
+            cmd="/bin/true",
+            description="event_hook",
+            runner={"type": "rps", "rps": 3, "times": 10})
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        results = json.loads(rally("task results"))
+        hook_results = results[0]["hooks"]
+        hooks_cfg = cfg["Dummy.dummy"][0]["hooks"]
+        expected = [self._get_result(hooks_cfg[0], iterations=[5])]
+        self.assertEqual(expected, hook_results)
+        self._assert_results_time(hook_results)
+
+    def test_hook_result_with_serial_runner(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config(
+            cmd="/bin/true",
+            description="event_hook",
+            runner={"type": "serial", "times": 10})
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        results = json.loads(rally("task results"))
+        hook_results = results[0]["hooks"]
+        hooks_cfg = cfg["Dummy.dummy"][0]["hooks"]
+        expected = [self._get_result(hooks_cfg[0], iterations=[5])]
+        self.assertEqual(expected, hook_results)
+        self._assert_results_time(hook_results)
+
+    def test_hook_result_error(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config(
+            cmd="/bin/false",
+            description="event_hook",
+            runner={"type": "constant", "times": 20, "concurrency": 3})
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        results = json.loads(rally("task results"))
+        hook_results = results[0]["hooks"]
+        hooks_cfg = cfg["Dummy.dummy"][0]["hooks"]
+        expected = [self._get_result(hooks_cfg[0], iterations=[5], error=True)]
+        self.assertEqual(expected, hook_results)
+        self._assert_results_time(hook_results)
+
+    def test_time_hook(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config(
+            cmd="/bin/true",
+            description="event_hook",
+            runner={"type": "constant_for_duration",
+                    "concurrency": 3, "duration": 10})
+        cfg["Dummy.dummy"][0]["hooks"].append({
+            "name": "sys_call",
+            "description": "time_hook",
+            "args": "/bin/true",
+            "trigger": {
+                "name": "event",
+                "args": {
+                    "unit": "time",
+                    "at": [3, 6, 9],
+                }
+            }
+        })
+
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        results = json.loads(rally("task results"))
+        hook_results = results[0]["hooks"]
+
+        hooks_cfg = cfg["Dummy.dummy"][0]["hooks"]
+        expected = [self._get_result(hooks_cfg[0], iterations=[5]),
+                    self._get_result(hooks_cfg[1], seconds=[3, 6, 9])]
+        self.assertEqual(expected, hook_results)
+        self._assert_results_time(hook_results)
