@@ -13,17 +13,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_utils import encodeutils
-from six.moves import configparser
-
+import copy
 import inspect
 import json
 import os
-import pwd
 import shutil
 import subprocess
 import tempfile
 
+
+from oslo_utils import encodeutils
+from six.moves import configparser
+
+
 TEST_ENV = {
     "OS_USERNAME": "admin",
     "OS_PASSWORD": "admin",
@@ -34,17 +36,21 @@ TEST_ENV = {
 DEPLOYMENT_FILE = "/tmp/rally_functests_main_deployment.json"
 
 
-class RallyCmdError(Exception):
+class RallyCliError(Exception):
 
-    def __init__(self, code, output):
+    def __init__(self, cmd, code, output):
+        self.command = cmd
         self.code = code
         self.output = encodeutils.safe_decode(output)
+        self.msg = "Command: %s Code: %d Output: %s\n" % (self.command,
+                                                          self.code,
+                                                          self.output)
 
     def __str__(self):
-        return "Code: %d Output: %s\n" % (self.code, self.output)
+        return self.msg
 
     def __unicode__(self):
-        return "Code: %d Output: %s\n" % (self.code, self.output)
+        return self.msg
 
 
 class TaskConfig(object):
@@ -70,17 +76,18 @@ class Rally(object):
 
     """
 
-    def __init__(self, fake=False):
-        # NOTE(sskripnick): we shoud change home dir to avoid races
-        # and do not touch any user files in ~/.rally
-        os.environ["HOME"] = pwd.getpwuid(os.getuid()).pw_dir
+    def __init__(self, fake=False, force_new_db=False):
         if not os.path.exists(DEPLOYMENT_FILE):
-            subprocess.call("rally deployment config > %s" % DEPLOYMENT_FILE,
-                            shell=True)
-        self.tmp_dir = tempfile.mkdtemp()
-        os.environ["HOME"] = self.tmp_dir
+            subprocess.call(["rally", "deployment", "config"],
+                            stdout=open(DEPLOYMENT_FILE, "w"))
 
-        if "RCI_KEEP_DB" not in os.environ:
+        # NOTE(sskripnick): we should change home dir to avoid races
+        # and do not touch any user files in ~/.rally
+        self.tmp_dir = tempfile.mkdtemp()
+        self.env = copy.deepcopy(os.environ)
+        self.env["HOME"] = self.tmp_dir
+
+        if force_new_db or ("RCI_KEEP_DB" not in os.environ):
             config_filename = os.path.join(self.tmp_dir, "conf")
             config = configparser.RawConfigParser()
             config.add_section("database")
@@ -90,10 +97,10 @@ class Rally(object):
                 config.write(conf)
             self.args = ["rally", "--config-file", config_filename]
             subprocess.call(["rally-manage", "--config-file", config_filename,
-                             "db", "recreate"])
+                             "db", "recreate"], env=self.env)
         else:
             self.args = ["rally"]
-            subprocess.call(["rally-manage", "db", "recreate"])
+            subprocess.call(["rally-manage", "db", "recreate"], env=self.env)
 
         self.reports_root = os.environ.get("REPORTS_ROOT",
                                            "rally-cli-output-files")
@@ -169,7 +176,7 @@ class Rally(object):
             cmd = cmd.split(" ")
         try:
             output = encodeutils.safe_decode(subprocess.check_output(
-                self.args + cmd, stderr=subprocess.STDOUT))
+                self.args + cmd, stderr=subprocess.STDOUT, env=self.env))
 
             if write_report:
                 if not report_path:
@@ -184,4 +191,14 @@ class Rally(object):
                 return json.loads(output)
             return output
         except subprocess.CalledProcessError as e:
-            raise RallyCmdError(e.returncode, e.output)
+            raise RallyCliError(cmd, e.returncode, e.output)
+
+
+def get_global(global_key, env):
+    home_dir = env.get("HOME")
+    with open("%s/.rally/globals" % home_dir) as f:
+        for line in f.readlines():
+            if line.startswith("%s=" % global_key):
+                key, value = line.split("=")
+                return value.rstrip()
+    return ""
