@@ -145,6 +145,7 @@ class TaskCommandsTestCase(test.TestCase):
                           "some_task", "task_args",
                           "task_args_file", deployment)
 
+    @mock.patch("rally.cli.commands.task.version")
     @mock.patch("rally.cli.commands.task.os.path.isfile", return_value=True)
     @mock.patch("rally.cli.commands.task.api.Task.create",
                 return_value=fakes.FakeTask(uuid="some_new_uuid", tag="tag"))
@@ -158,10 +159,11 @@ class TaskCommandsTestCase(test.TestCase):
     @mock.patch("rally.cli.commands.task.api.Task.start")
     def test_start(self, mock_task_start, mock_task_validate, mock__load_task,
                    mock_detailed, mock_use, mock_task_create,
-                   mock_os_path_isfile):
+                   mock_os_path_isfile, mock_version):
         deployment_id = "e0617de9-77d1-4875-9b49-9d5789e29f20"
         task_path = "path_to_config.json"
         self.task.start(task_path, deployment_id, do_use=True)
+        mock_version.version_string.assert_called_once_with()
         mock_task_create.assert_called_once_with(
             deployment_id, None)
         mock_task_start.assert_called_once_with(
@@ -324,8 +326,9 @@ class TaskCommandsTestCase(test.TestCase):
             "uuid": test_uuid,
             "status": consts.TaskStatus.FAILED,
             "results": [],
-            "verification_log": json.dumps(["error_type", "error_message",
-                                            "error_traceback"])
+            "verification_log": json.dumps({"etype": "error_type",
+                                            "msg": "error_message",
+                                            "trace": "error_traceback"})
         }
         mock_task.get_detailed = mock.MagicMock(return_value=value)
 
@@ -334,14 +337,14 @@ class TaskCommandsTestCase(test.TestCase):
         verification = yaml.safe_load(value["verification_log"])
         if debug:
             expected_calls = [mock.call("Task test_task_id: failed"),
-                              mock.call("%s" % verification[2])]
+                              mock.call("%s" % verification["trace"])]
             mock_stdout.write.assert_has_calls(expected_calls, any_order=True)
         else:
             expected_calls = [mock.call("Task test_task_id: failed"),
-                              mock.call("%s" % verification[0]),
-                              mock.call("%s" % verification[1]),
+                              mock.call("%s" % verification["etype"]),
+                              mock.call("%s" % verification["msg"]),
                               mock.call("\nFor more details run:\nrally "
-                                        "-vd task detailed %s" % test_uuid)]
+                                        "-d task detailed %s" % test_uuid)]
             mock_stdout.write.assert_has_calls(expected_calls, any_order=True)
 
     @mock.patch("rally.cli.commands.task.api.Task")
@@ -384,6 +387,7 @@ class TaskCommandsTestCase(test.TestCase):
         task_id = "foo_task_id"
         data = [
             {"key": "foo_key", "data": {"raw": "foo_raw", "sla": [],
+                                        "hooks": [],
                                         "load_duration": 1.0,
                                         "full_duration": 2.0}}
         ]
@@ -391,6 +395,7 @@ class TaskCommandsTestCase(test.TestCase):
                                 "result": x["data"]["raw"],
                                 "load_duration": x["data"]["load_duration"],
                                 "full_duration": x["data"]["full_duration"],
+                                "hooks": x["data"]["hooks"],
                                 "sla": x["data"]["sla"]}, data)
         fake_task = fakes.FakeTask({"status": consts.TaskStatus.FINISHED})
         fake_task.get_results = mock.MagicMock(return_value=data)
@@ -426,6 +431,7 @@ class TaskCommandsTestCase(test.TestCase):
         return [{"key": {"name": key, "pos": 0},
                  "data": {"raw": key + "_raw",
                           "sla": key + "_sla",
+                          "hooks": key + "_hooks",
                           "load_duration": 1.2,
                           "full_duration": 2.3}} for key in keys]
 
@@ -454,8 +460,10 @@ class TaskCommandsTestCase(test.TestCase):
                                out="output.html", out_format="html")
         expected = [
             {"load_duration": 1.2, "full_duration": 2.3, "sla": "bar_sla",
+             "hooks": "bar_hooks",
              "key": {"name": "bar", "pos": 0}, "result": "bar_raw"},
             {"load_duration": 1.2, "full_duration": 2.3, "sla": "spam_sla",
+             "hooks": "spam_hooks",
              "key": {"name": "spam", "pos": 0}, "result": "spam_raw"},
             "result_1_from_file", "result_2_from_file"]
         mock_plot.trends.assert_called_once_with(expected)
@@ -552,16 +560,19 @@ class TaskCommandsTestCase(test.TestCase):
         data = [
             {"key": {"name": "class.test", "pos": 0},
              "data": {"raw": "foo_raw", "sla": "foo_sla",
+                      "hooks": "foo_hooks",
                       "load_duration": 0.1,
                       "full_duration": 1.2}},
             {"key": {"name": "class.test", "pos": 0},
              "data": {"raw": "bar_raw", "sla": "bar_sla",
+                      "hooks": "bar_hooks",
                       "load_duration": 2.1,
                       "full_duration": 2.2}}]
 
         results = [{"key": x["key"],
                     "result": x["data"]["raw"],
                     "sla": x["data"]["sla"],
+                    "hooks": x["data"]["hooks"],
                     "load_duration": x["data"]["load_duration"],
                     "full_duration": x["data"]["full_duration"]}
                    for x in data]
@@ -618,10 +629,12 @@ class TaskCommandsTestCase(test.TestCase):
         data = [
             {"key": {"name": "test", "pos": 0},
              "data": {"raw": "foo_raw", "sla": "foo_sla",
+                      "hooks": "foo_hooks",
                       "load_duration": 0.1,
                       "full_duration": 1.2}},
             {"key": {"name": "test", "pos": 0},
              "data": {"raw": "bar_raw", "sla": "bar_sla",
+                      "hooks": "bar_hooks",
                       "load_duration": 2.1,
                       "full_duration": 2.2}}]
 
@@ -631,6 +644,7 @@ class TaskCommandsTestCase(test.TestCase):
                 map(lambda x: {"key": x["key"],
                                "result": x["data"]["raw"],
                                "sla": x["data"]["sla"],
+                               "hooks": x["data"]["hooks"],
                                "load_duration": x["data"]["load_duration"],
                                "full_duration": x["data"]["full_duration"]},
                     data))
