@@ -57,8 +57,8 @@ class VerifyCommandsTestCase(test.TestCase):
 
         mock_verification_verify.assert_called_once_with(
             deployment_id, set_name="full", regex=None, tests_file=None,
-            tempest_config=None, expected_failures=None,
-            system_wide=False, concur=0, failing=False)
+            tests_file_to_skip=None, tempest_config=None,
+            expected_failures=None, system_wide=False, concur=0, failing=False)
 
     @mock.patch("rally.osclients.Clients")
     @mock.patch("rally.api.Verification.verify")
@@ -75,8 +75,8 @@ class VerifyCommandsTestCase(test.TestCase):
 
         mock_verification_verify.assert_called_once_with(
             deployment_id, set_name="full", regex=None, tests_file=None,
-            tempest_config=tempest_config.name, expected_failures=None,
-            system_wide=False, concur=0, failing=False)
+            tests_file_to_skip=None, tempest_config=tempest_config.name,
+            expected_failures=None, system_wide=False, concur=0, failing=False)
         tempest_config.close()
 
     @mock.patch("rally.api.Verification.verify")
@@ -90,8 +90,8 @@ class VerifyCommandsTestCase(test.TestCase):
 
         mock_verification_verify.assert_called_once_with(
             deployment_id, set_name="", regex=None, tests_file=tests_file,
-            tempest_config=None, expected_failures=None, system_wide=False,
-            concur=0, failing=False)
+            tests_file_to_skip=None, tempest_config=None,
+            expected_failures=None, system_wide=False, concur=0, failing=False)
 
     @mock.patch("rally.api.Verification.verify")
     @mock.patch("six.moves.builtins.open",
@@ -106,8 +106,9 @@ class VerifyCommandsTestCase(test.TestCase):
 
         mock_verification_verify.assert_called_once_with(
             deployment_id, set_name="full", regex=None, tests_file=None,
-            tempest_config=None, expected_failures={"test": "reason of fail"},
-            system_wide=False, concur=0, failing=False)
+            tests_file_to_skip=None, tempest_config=None,
+            expected_failures={"test": "reason of fail"}, system_wide=False,
+            concur=0, failing=False)
 
     @mock.patch("rally.api.Verification.verify")
     def test_start_with_wrong_set_name(self, mock_verification_verify):
@@ -121,6 +122,30 @@ class VerifyCommandsTestCase(test.TestCase):
                          consts.TempestTestsAPI)
         self.assertFalse(mock_verification_verify.called)
 
+    @mock.patch("rally.api.Verification.verify")
+    def test_start_with_set_name_and_regex(self, mock_verification_verify):
+        deployment_id = "2856e214-90d1-4d82-9402-dd13973ca0f6"
+
+        set_name = "identity"
+        regex = "tempest.api.compute"
+        self.verify.start(set_name=set_name, regex=regex,
+                          deployment=deployment_id, do_use=False)
+
+        self.assertFalse(mock_verification_verify.called)
+
+    @mock.patch("rally.api.Verification.verify")
+    def test_start_with_tests_file_and_tests_file_to_skip(
+            self, mock_verification_verify):
+        deployment_id = "3580e214-90d1-4d82-9402-dd13973ca0f6"
+
+        tests_file = "/path/to/tests/file-1"
+        tests_file_to_skip = "/path/to/tests/file-2"
+        self.verify.start(tests_file=tests_file,
+                          tests_file_to_skip=tests_file_to_skip,
+                          deployment=deployment_id, do_use=False)
+
+        self.assertFalse(mock_verification_verify.called)
+
     @mock.patch("rally.api.Verification.verify")
     def test_start_with_failing_and_set_name(self, mock_verification_verify):
         deployment_id = "f2009aae-6ef3-468e-96b2-3c987d584010"
@@ -131,6 +156,16 @@ class VerifyCommandsTestCase(test.TestCase):
 
         self.assertFalse(mock_verification_verify.called)
 
+    @mock.patch("rally.api.Verification.verify")
+    def test_start_with_failing_and_regex(self, mock_verification_verify):
+        deployment_id = "25d19aec-f39e-459e-b3d5-24a718e92233"
+
+        regex = "tempest.api.compute"
+        self.verify.start(regex=regex, deployment=deployment_id, do_use=False,
+                          failing=True)
+
+        self.assertFalse(mock_verification_verify.called)
+
     @mock.patch("rally.api.Verification.verify")
     @mock.patch("os.path.exists", return_value=True)
     def test_start_with_failing_and_test_files(self, mock_exists,
@@ -143,6 +178,18 @@ class VerifyCommandsTestCase(test.TestCase):
 
         self.assertFalse(mock_verification_verify.called)
 
+    @mock.patch("rally.api.Verification.verify")
+    @mock.patch("os.path.exists", return_value=True)
+    def test_start_with_failing_and_test_files_to_skip(
+            self, mock_exists, mock_verification_verify):
+        deployment_id = "7902051d-8286-4cfc-aec5-addde73b3a1f"
+
+        tests_file = "/path/to/tests/file"
+        self.verify.start(tests_file_to_skip=tests_file,
+                          deployment=deployment_id, do_use=False, failing=True)
+
+        self.assertFalse(mock_verification_verify.called)
+
     @mock.patch("rally.api.Verification.import_results")
     def test_import_results(self, mock_verification_import_results):
         deployment_id = "fake_deployment_uuid"
@@ -396,7 +443,7 @@ class VerifyCommandsTestCase(test.TestCase):
         deployment_id = "14377d10-ca77-4104-aba8-36edebcfc120"
         self.verify.genconfig(deployment_id)
         mock_verification_configure_tempest.assert_called_once_with(
-            deployment_id, None, False)
+            deployment_id, None, None, False)
 
     @mock.patch("rally.api.Verification.configure_tempest")
     def test_genconfig_with_config_specified(
@@ -405,7 +452,19 @@ class VerifyCommandsTestCase(test.TestCase):
         tempest_conf = "/tmp/tempest.conf"
         self.verify.genconfig(deployment_id, tempest_config=tempest_conf)
         mock_verification_configure_tempest.assert_called_once_with(
-            deployment_id, tempest_conf, False)
+            deployment_id, tempest_conf, None, False)
+
+    @mock.patch("rally.api.Verification.configure_tempest")
+    @mock.patch("six.moves.configparser.ConfigParser")
+    @mock.patch("os.path.exists", return_value=True)
+    def test_genconfig_with_extra_conf_path_specified(
+            self, mock_exists, mock_config_parser,
+            mock_verification_configure_tempest):
+        deployment_id = "68b501af-a553-431c-83ac-30f93a112231"
+        extra_conf_path = "/tmp/extra.conf"
+        self.verify.genconfig(deployment_id, extra_conf_path=extra_conf_path)
+        mock_verification_configure_tempest.assert_called_once_with(
+            deployment_id, None, mock_config_parser(), False)
 
     @mock.patch("rally.api.Verification.configure_tempest")
     def test_genconfig_override_config(
@@ -413,17 +472,21 @@ class VerifyCommandsTestCase(test.TestCase):
         deployment_id = "cd5b64ad-c12f-4781-a89e-95535b145a11"
         self.verify.genconfig(deployment_id, override=True)
         mock_verification_configure_tempest.assert_called_once_with(
-            deployment_id, None, True)
+            deployment_id, None, None, True)
 
     @mock.patch("rally.api.Verification.configure_tempest")
-    def test_genconfig_with_config_specified_and_override_config(
-            self, mock_verification_configure_tempest):
+    @mock.patch("six.moves.configparser.ConfigParser")
+    @mock.patch("os.path.exists", return_value=True)
+    def test_genconfig_with_all_args_specified(
+            self, mock_exists, mock_config_parser,
+            mock_verification_configure_tempest):
         deployment_id = "89982aba-efef-48cb-8d94-ca893b4e78a6"
-        tempest_conf = "/tmp/tempest.conf"
-        self.verify.genconfig(deployment_id,
-                              tempest_config=tempest_conf, override=True)
+        tempest_conf_path = "/tmp/tempest.conf"
+        extra_conf_path = "/tmp/extra-tempest.conf"
+        self.verify.genconfig(deployment_id, tempest_config=tempest_conf_path,
+                              extra_conf_path=extra_conf_path, override=True)
         mock_verification_configure_tempest.assert_called_once_with(
-            deployment_id, tempest_conf, True)
+            deployment_id, tempest_conf_path, mock_config_parser(), True)
 
     @mock.patch("rally.api.Verification.install_tempest")
     def test_install(self, mock_verification_install_tempest):
@@ -483,7 +546,7 @@ class VerifyCommandsTestCase(test.TestCase):
             deployment_uuid, None, version, False)
 
     @mock.patch("rally.api.Verification.install_tempest_plugin")
-    def test_install_plugin_from_url(
+    def test_installplugin_from_url(
             self, mock_verification_install_tempest_plugin):
         deployment_uuid = "83514de2-a770-4e28-82dd-2826b725e733"
         url = "https://github.com/fake/plugin"
@@ -492,7 +555,7 @@ class VerifyCommandsTestCase(test.TestCase):
             deployment_uuid, url, None, False)
 
     @mock.patch("rally.api.Verification.install_tempest_plugin")
-    def test_install_plugin_from_path(
+    def test_installplugin_from_path(
             self, mock_verification_install_tempest_plugin):
         deployment_uuid = "83514de2-a770-4e28-82dd-2826b725e733"
         path = "/tmp/fake/plugin"
@@ -500,12 +563,27 @@ class VerifyCommandsTestCase(test.TestCase):
         mock_verification_install_tempest_plugin.assert_called_once_with(
             deployment_uuid, path, None, False)
 
+    @mock.patch("rally.api.Verification.list_tempest_plugins")
+    def test_listplugins(self, mock_verification_list_tempest_plugins):
+        deployment_uuid = "83514de2-a770-4e28-82dd-2826b725e733"
+        self.verify.listplugins(deployment_uuid)
+        mock_verification_list_tempest_plugins.assert_called_once_with(
+            deployment_uuid, False)
+
+    @mock.patch("rally.api.Verification.uninstall_tempest_plugin")
+    def test_uninstallplugin(
+            self, mock_verification_uninstall_tempest_plugin):
+        deployment_uuid = "83514de2-a770-4e28-82dd-2826b725e733"
+        self.verify.uninstallplugin(deployment_uuid, "fake-plugin")
+        mock_verification_uninstall_tempest_plugin.assert_called_once_with(
+            deployment_uuid, "fake-plugin", False)
+
     @mock.patch("rally.api.Verification.discover_tests")
     def test_discover(self, mock_verification_discover_tests):
         deployment_uuid = "97725f22-1cd2-46a5-8c62-3cdc36ed6d2a"
         self.verify.discover(deployment_uuid, "some_pattern")
         mock_verification_discover_tests.assert_called_once_with(
-            deployment_uuid, "some_pattern")
+            deployment_uuid, "some_pattern", False)
 
     @mock.patch("rally.api.Verification.show_config_info")
     def test_showconfig(self, mock_verification_show_config_info):
