@@ -189,9 +189,11 @@ class TaskTestCase(test.TestCase):
              "id": 11, "key": {"kw": {"foo": 42},
                                "name": "Foo.bar", "pos": 0},
              "data": {"raw": iterations, "sla": [],
+                      "hooks": [],
                       "full_duration": 40, "load_duration": 32}}]
         expected = [
             {"iterations": "foo_iterations", "sla": [],
+             "hooks": [],
              "key": {"kw": {"foo": 42}, "name": "Foo.bar", "pos": 0},
              "info": {
                  "atomic": {"keystone.create_user": {"max_duration": 19,
@@ -249,8 +251,9 @@ class TaskTestCase(test.TestCase):
         mock_task_update.assert_called_once_with(
             self.task["uuid"],
             {"status": consts.TaskStatus.FAILED,
-             "verification_log": "[\"foo_type\", \"foo_error_message\", "
-                                 "\"foo_trace\"]"},
+             "verification_log": json.dumps({"etype": "foo_type",
+                                             "msg": "foo_error_message",
+                                             "trace": "foo_trace"})},
         )
 
     @ddt.data(
