@@ -65,6 +65,29 @@ class QuotaMixinTestCase(test.TestCase):
         self.assertEqual([quota.tenant_uuid], quota.list())
 
 
+class MagnumMixinTestCase(test.TestCase):
+
+    def test_id(self):
+        magnum = resources.MagnumMixin()
+        magnum._service = "magnum"
+        magnum.raw_resource = mock.MagicMock()
+        self.assertEqual(magnum.raw_resource.uuid, magnum.id())
+
+    def test_list(self):
+        magnum = resources.MagnumMixin()
+        magnum._service = "magnum"
+        some_resources = [mock.MagicMock(), mock.MagicMock(),
+                          mock.MagicMock(), mock.MagicMock()]
+        magnum._manager = mock.MagicMock()
+        magnum._manager.return_value.list.side_effect = (
+            some_resources[:2], some_resources[2:4], [])
+        self.assertEqual(some_resources, magnum.list())
+        self.assertEqual(
+            [mock.call(marker=None), mock.call(marker=some_resources[1].uuid),
+             mock.call(marker=some_resources[3].uuid)],
+            magnum._manager.return_value.list.call_args_list)
+
+
 class NovaServerTestCase(test.TestCase):
 
     def test_list(self):
@@ -150,6 +173,22 @@ class NovaFlavorsTestCase(test.TestCase):
         self.assertRaises(TypeError, flavor.is_deleted)
 
 
+class NovaAggregatesTestCase(test.TestCase):
+
+    @mock.patch("%s.base.ResourceManager._manager" % BASE)
+    @mock.patch("rally.common.utils.name_matches_object")
+    def test_list(self, mock_name_matches_object,
+                  mock_resource_manager__manager):
+        aggregates = [mock.MagicMock(name="rally_foo1"),
+                      mock.MagicMock(name="rally_foo2"),
+                      mock.MagicMock(name="foo3")]
+        mock_name_matches_object.side_effect = [False, True, True]
+        mock_resource_manager__manager().list.return_value = aggregates
+        self.assertEqual(aggregates[1:], resources.NovaAggregate().list())
+        mock_name_matches_object.assert_has_calls(
+            [mock.call(r.name, nutils.NovaScenario) for r in aggregates])
+
+
 class NovaSecurityGroupTestCase(test.TestCase):
 
     @mock.patch("%s.base.ResourceManager._manager" % BASE)
@@ -879,4 +918,4 @@ class WatcherActionPlanTestCase(test.TestCase):
         watcher.list()
 
         self.assertEqual("action_plan", watcher._resource)
-        watcher._manager().list.assert_called_once_with(limit=0)
\ No newline at end of file
+        watcher._manager().list.assert_called_once_with(limit=0)
