@@ -841,6 +841,18 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.list_hypervisors")
 
+    def test__get_hypervisor(self):
+        hypervisor = mock.Mock()
+        nova_scenario = utils.NovaScenario()
+        result = nova_scenario._get_hypervisor(hypervisor)
+        self.assertEqual(
+            self.admin_clients("nova").hypervisors.get.return_value,
+            result)
+        self.admin_clients("nova").hypervisors.get.assert_called_once_with(
+            hypervisor)
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.get_hypervisor")
+
     def test__list_images(self):
         nova_scenario = utils.NovaScenario()
         result = nova_scenario._list_images(detailed=False, fakearg="fakearg")
@@ -909,6 +921,19 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.list_flavors")
 
+    def test__set_flavor_keys(self):
+        flavor = mock.MagicMock()
+        nova_scenario = utils.NovaScenario()
+        extra_specs = {"fakeargs": "foo"}
+        flavor.set_keys = mock.MagicMock()
+
+        result = nova_scenario._set_flavor_keys(flavor, extra_specs)
+        self.assertEqual(flavor.set_keys.return_value, result)
+        flavor.set_keys.assert_called_once_with(extra_specs)
+
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.set_flavor_keys")
+
     @ddt.data({},
               {"hypervisor": "foo_hypervisor"})
     @ddt.unpack
@@ -995,6 +1020,17 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.create_flavor")
 
+    def test__get_flavor(self):
+        nova_scenario = utils.NovaScenario()
+        result = nova_scenario._get_flavor("foo_flavor_id")
+        self.assertEqual(
+            self.admin_clients("nova").flavors.get.return_value,
+            result)
+        self.admin_clients("nova").flavors.get.assert_called_once_with(
+            "foo_flavor_id")
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.get_flavor")
+
     def test__update_server(self):
         server = mock.Mock()
         nova_scenario = utils.NovaScenario()
@@ -1019,3 +1055,67 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
 
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.update_server")
+
+    def test_create_aggregate(self):
+        nova_scenario = utils.NovaScenario(context=self.context)
+        random_name = "random_name"
+        nova_scenario.generate_random_name = mock.Mock(
+            return_value=random_name)
+        result = nova_scenario._create_aggregate("nova")
+        self.assertEqual(
+            self.admin_clients("nova").aggregates.create.return_value,
+            result)
+        self.admin_clients("nova").aggregates.create.assert_called_once_with(
+            random_name, "nova")
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.create_aggregate")
+
+    def test_delete_aggregate(self):
+        nova_scenario = utils.NovaScenario(context=self.context)
+        result = nova_scenario._delete_aggregate("fake_aggregate")
+        self.assertEqual(
+            self.admin_clients("nova").aggregates.delete.return_value,
+            result)
+        self.admin_clients("nova").aggregates.delete.assert_called_once_with(
+            "fake_aggregate")
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.delete_aggregate")
+
+    def test_update_aggregate(self):
+        aggregate = mock.Mock()
+        nova_scenario = utils.NovaScenario(context=self.context)
+        nova_scenario.generate_random_name = mock.Mock(
+            return_value="random_name")
+        values = {"name": "random_name",
+                  "availability_zone": "random_name"}
+        result = nova_scenario._update_aggregate(aggregate=aggregate)
+        self.assertEqual(
+            self.admin_clients("nova").aggregates.update.return_value,
+            result)
+        self.admin_clients("nova").aggregates.update.assert_called_once_with(
+            aggregate, values)
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.update_aggregate")
+
+    def test_aggregate_add_host(self):
+        nova_scenario = utils.NovaScenario(context=self.context)
+        result = nova_scenario._aggregate_add_host("fake_agg", "fake_host")
+        self.assertEqual(
+            self.admin_clients("nova").aggregates.add_host.return_value,
+            result)
+        self.admin_clients("nova").aggregates.add_host.assert_called_once_with(
+            "fake_agg", "fake_host")
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.aggregate_add_host")
+
+    def test_aggregate_remove_host(self):
+        nova_scenario = utils.NovaScenario(context=self.context)
+        result = nova_scenario._aggregate_remove_host("fake_agg", "fake_host")
+        self.assertEqual(
+            self.admin_clients("nova").aggregates.remove_host.return_value,
+            result)
+        self.admin_clients(
+            "nova").aggregates.remove_host.assert_called_once_with(
+            "fake_agg", "fake_host")
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.aggregate_remove_host")
