@@ -61,6 +61,24 @@ class GlanceV1WrapperTestCase(test.ScenarioTestCase):
         self.owner = mock.Mock()
         self.wrapped_client = glance_wrapper.wrap(self.client, self.owner)
 
+    def test_get_image(self):
+        image = mock.Mock()
+
+        return_image = self.wrapped_client.get_image(image)
+
+        self.client.return_value.images.get.assert_called_once_with(image.id)
+        self.assertEqual(return_image,
+                         self.client.return_value.images.get.return_value)
+
+    def test_get_image_not_found(self):
+        image = mock.Mock()
+        self.client.return_value.images.get.side_effect = (
+            glance_exc.HTTPNotFound)
+
+        self.assertRaises(exceptions.GetResourceNotFound,
+                          self.wrapped_client.get_image, image)
+        self.client.return_value.images.get.assert_called_once_with(image.id)
+
     @ddt.data(
         {"location": "image_location", "visibility": "private"},
         {"location": "image_location", "fakearg": "fake"},
@@ -91,24 +109,24 @@ class GlanceV1WrapperTestCase(test.ScenarioTestCase):
 
         self.mock_wait_for_status.mock.assert_called_once_with(
             self.client().images.create.return_value, ["active"],
-            update_resource=self.mock_get_from_manager.mock.return_value,
+            update_resource=self.wrapped_client.get_image,
             check_interval=CONF.benchmark.glance_image_create_poll_interval,
             timeout=CONF.benchmark.glance_image_create_timeout)
-        self.mock_get_from_manager.mock.assert_called_once_with()
         self.assertEqual(self.mock_wait_for_status.mock.return_value,
                          return_image)
 
-    def test_delete_image(self):
+    @ddt.data({"expected": True},
+              {"visibility": "public", "expected": True},
+              {"visibility": "private", "expected": False})
+    @ddt.unpack
+    def test_set_visibility(self, visibility=None, expected=None):
         image = mock.Mock()
-        self.wrapped_client.delete_image(image)
-        image.delete.assert_called_once_with()
-        self.mock_wait_for_status.mock.assert_called_once_with(
-            image, ["deleted"],
-            check_deletion=True,
-            update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.glance_image_delete_poll_interval,
-            timeout=CONF.benchmark.glance_image_delete_timeout)
-        self.mock_get_from_manager.mock.assert_called_once_with()
+        if visibility is None:
+            self.wrapped_client.set_visibility(image)
+        else:
+            self.wrapped_client.set_visibility(image, visibility=visibility)
+        self.client().images.update.assert_called_once_with(
+            image.id, is_public=expected)
 
     @ddt.data({}, {"fakearg": "fake"})
     def test_list_images_basic(self, filters):
@@ -157,22 +175,22 @@ class GlanceV2WrapperTestCase(test.ScenarioTestCase):
         self.owner = mock.Mock()
         self.wrapped_client = glance_wrapper.wrap(self.client, self.owner)
 
-    def test__update_image(self):
+    def test_get_image(self):
         image = mock.Mock()
 
-        return_image = self.wrapped_client._update_image(image)
+        return_image = self.wrapped_client.get_image(image)
 
         self.client.return_value.images.get.assert_called_once_with(image.id)
         self.assertEqual(return_image,
                          self.client.return_value.images.get.return_value)
 
-    def test__update_image_not_found(self):
+    def test_get_image_not_found(self):
         image = mock.Mock()
         self.client.return_value.images.get.side_effect = (
             glance_exc.HTTPNotFound)
 
         self.assertRaises(exceptions.GetResourceNotFound,
-                          self.wrapped_client._update_image, image)
+                          self.wrapped_client.get_image, image)
         self.client.return_value.images.get.assert_called_once_with(image.id)
 
     @ddt.data(
@@ -185,7 +203,7 @@ class GlanceV2WrapperTestCase(test.ScenarioTestCase):
     @mock.patch("requests.get")
     def test_create_image(self, mock_requests_get, mock_open, location,
                           **kwargs):
-        self.wrapped_client._update_image = mock.Mock()
+        self.wrapped_client.get_image = mock.Mock()
         created_image = mock.Mock()
         uploaded_image = mock.Mock()
         self.mock_wait_for_status.mock.side_effect = [created_image,
@@ -216,29 +234,31 @@ class GlanceV2WrapperTestCase(test.ScenarioTestCase):
         self.mock_wait_for_status.mock.assert_has_calls([
             mock.call(
                 self.client().images.create.return_value, ["queued"],
-                update_resource=self.wrapped_client._update_image,
+                update_resource=self.wrapped_client.get_image,
                 check_interval=CONF.benchmark.
                 glance_image_create_poll_interval,
                 timeout=CONF.benchmark.glance_image_create_timeout),
             mock.call(
                 created_image, ["active"],
-                update_resource=self.wrapped_client._update_image,
+                update_resource=self.wrapped_client.get_image,
                 check_interval=CONF.benchmark.
                 glance_image_create_poll_interval,
                 timeout=mock.ANY)])
         self.assertEqual(uploaded_image, return_image)
 
-    def test_delete_image(self):
+    @ddt.data({},
+              {"visibility": "public"},
+              {"visibility": "private"})
+    @ddt.unpack
+    def test_set_visibility(self, visibility=None):
         image = mock.Mock()
-        self.wrapped_client.delete_image(image)
-        self.client.return_value.images.delete.assert_called_once_with(
-            image.id)
-        self.mock_wait_for_status.mock.assert_called_once_with(
-            image, ["deleted"],
-            check_deletion=True,
-            update_resource=self.wrapped_client._update_image,
-            check_interval=CONF.benchmark.glance_image_delete_poll_interval,
-            timeout=CONF.benchmark.glance_image_delete_timeout)
+        if visibility is None:
+            self.wrapped_client.set_visibility(image)
+            visibility = "public"
+        else:
+            self.wrapped_client.set_visibility(image, visibility=visibility)
+        self.client().images.update.assert_called_once_with(
+            image.id, visibility=visibility)
 
     @ddt.data({}, {"fakearg": "fake"})
     def test_list_images(self, filters):
